summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rwxr-xr-xtools/install.sh8
1 files changed, 5 insertions, 3 deletions
diff --git a/tools/install.sh b/tools/install.sh
index 4582ed03e..3ea12f8d4 100755
--- a/tools/install.sh
+++ b/tools/install.sh
@@ -61,9 +61,9 @@ custom_zsh=${ZSH:+yes}
zdot="${ZDOTDIR:-$HOME}"
# Default value for $ZSH
# a) if $ZDOTDIR is supplied: $ZDOTDIR/ohmyzsh
# b) otherwise, $HOME/.oh-my-zsh
-ZSH="${ZSH:-${ZDOTDIR:+$ZDOTDIR/ohmyzsh}}"
+[ "$ZDOTDIR" = "$HOME" ] || ZSH="${ZSH:-${ZDOTDIR:+$ZDOTDIR/ohmyzsh}}"
ZSH="${ZSH:-$HOME/.oh-my-zsh}"
# Default settings
@@ -350,7 +350,9 @@ setup_zshrc() {
# Modify $ZSH variable in .zshrc directory to use the literal $ZDOTDIR or $HOME
omz="$ZSH"
- [ -z "$ZDOTDIR" ] || omz=$(echo "$omz" | sed "s|^$ZDOTDIR/|\$ZDOTDIR/|")
+ if [ -n "$ZDOTDIR" ] && [ "$ZDOTDIR" != "$HOME" ]; then
+ omz=$(echo "$omz" | sed "s|^$ZDOTDIR/|\$ZDOTDIR/|")
+ fi
omz=$(echo "$omz" | sed "s|^$HOME/|\$HOME/|")
sed "s|^export ZSH=.*$|export ZSH=\"${omz}\"|" "$ZSH/templates/zshrc.zsh-template" > "$zdot/.zshrc-omztemp"
@@ -61,9 +61,9 @@ custom_zsh=${ZSH:+yes}
zdot="${ZDOTDIR:-$HOME}"
# Default value for $ZSH
-# a) if $ZDOTDIR is supplied: $ZDOTDIR/ohmyzsh
+# a) if $ZDOTDIR is supplied and not $HOME: $ZDOTDIR/ohmyzsh
# b) otherwise, $HOME/.oh-my-zsh